@@ -234,8 +234,8 @@ class fillVars(cl_base.glob_attr):
         replServers = replServers.split(",")
         for replServer in replServers:
             if replServer:
-                md5hex = hashlib.md5(replServer).hexdigest()
-                data8bit = "".join((str(int(x,16)/2) for x in list(md5hex)))
+                md5hex = hashlib.md5(replServer.encode("UTF-8")).hexdigest()
+                data8bit = "".join((str(int(x,16) // 2) for x in list(md5hex)))
                 dStart = 0
                 dEnd = 3
                 dMax = 32
